@@ -221,7 +221,7 @@ class IssueDAO extends DAO implements PKPPubIdPluginDAO {
 	 * @return Issue object
 	 */
 	function getByBestId($issueId, $contextId = null, $useCache = false) {
-		$params = [$issueId];
+		$params = [(string) $issueId];
 		if ($contextId) $params[] = (int) $contextId;
 
 		$result = $this->retrieve(
@@ -567,12 +567,15 @@ class IssueDAO extends DAO implements PKPPubIdPluginDAO {
 	 * @return DAOResultFactory
 	 */
 	function getIssues($journalId, $rangeInfo = null) {
+		$baseSql = '
+			FROM issues i WHERE journal_id = ?
+		';
 		$result = $this->retrieveRange(
-			$sql = 'SELECT i.* FROM issues i WHERE journal_id = ? ORDER BY current DESC, date_published DESC',
+			"SELECT i.* {$baseSql} ORDER BY current DESC, date_published DESC",
 			$params = [(int) $journalId], $rangeInfo
 		);
 
-		return new DAOResultFactory($result, $this, '_returnIssueFromRow', [], $sql, $params, $rangeInfo); // Counted in ExportableIssuesListGridHandler
+		return new DAOResultFactory($result, $this, '_returnIssueFromRow', [], "SELECT 0 {$baseSql}", $params, $rangeInfo); // Counted in ExportableIssuesListGridHandler
 	}
 
 	/**
@@ -626,24 +629,26 @@ class IssueDAO extends DAO implements PKPPubIdPluginDAO {
 			$params[] = $pubIdSettingValue;
 		}
 
-		$result = $this->retrieveRange(
-			$sql = 'SELECT i.*
+		$baseSql = '
 			FROM issues i
-				LEFT JOIN custom_issue_orders o ON (o.issue_id = i.issue_id)
-				' . ($pubIdType != null?' LEFT JOIN issue_settings ist ON (i.issue_id = ist.issue_id)':'')
-				. ($pubIdSettingName != null?' LEFT JOIN issue_settings iss ON (i.issue_id = iss.issue_id AND iss.setting_name = ?)':'') .'
+			LEFT JOIN custom_issue_orders o ON (o.issue_id = i.issue_id)
+			' . ($pubIdType != null?' LEFT JOIN issue_settings ist ON (i.issue_id = ist.issue_id)':'')
+			. ($pubIdSettingName != null?' LEFT JOIN issue_settings iss ON (i.issue_id = iss.issue_id AND iss.setting_name = ?)':'') .'
 			WHERE
 				i.published = 1  AND i.journal_id = ?
 				' . ($pubIdType != null?' AND ist.setting_name = ? AND ist.setting_value IS NOT NULL':'')
 				. (($pubIdSettingName != null && $pubIdSettingValue != null && $pubIdSettingValue == EXPORT_STATUS_NOT_DEPOSITED)?' AND iss.setting_value IS NULL':'')
 				. (($pubIdSettingName != null && $pubIdSettingValue != null && $pubIdSettingValue != EXPORT_STATUS_NOT_DEPOSITED)?' AND iss.setting_value = ?':'')
-				. (($pubIdSettingName != null && is_null($pubIdSettingValue))?' AND (iss.setting_value IS NULL OR iss.setting_value = \'\')':'')
-				.' ORDER BY i.date_published DESC',
+				. (($pubIdSettingName != null && is_null($pubIdSettingValue))?' AND (iss.setting_value IS NULL OR iss.setting_value = \'\')':'') . '
+		';
+
+		$result = $this->retrieveRange(
+			"SELECT i.* {$baseSql} ORDER BY i.date_published DESC",
 			$params,
 			$rangeInfo
 		);
 
-		return new DAOResultFactory($result, $this, '_returnIssueFromRow', [], $sql, $params, $rangeInfo);
+		return new DAOResultFactory($result, $this, '_returnIssueFromRow', [], "SELECT 0 {$baseSql}", $params, $rangeInfo);
 	}
 
 	/**
@@ -696,7 +701,7 @@ class IssueDAO extends DAO implements PKPPubIdPluginDAO {
 					'journal_id' => (int) $journalId,
 					'seq' => $i
 				],
-				['issue_id', 'journal_id']
+				['issue_id']
 			);
 			$result->next();
 		}
