@@ -47,11 +47,8 @@ class CitationListTokenizerFilter extends Filter {
 		} else {
 			$citations = explode("\n", $input);
 		}
-		// 4) Remove numbers from the beginning of each citation.
-		foreach($citations as $index => $citation) {
-			$citations[$index] = PKPString::regexp_replace('/^\s*[\[#]?[0-9]+[.)\]]?\s*/', '', $citation);
-		}
-
+		// 4) Remove whitespace from the beginning and the end of each citation.
+		$citations = array_map('trim', $citations);
 		return $citations;
 	}
 }
