@@ -3,9 +3,9 @@
 /**
  * @file classes/core/PKPRouter.inc.php
  *
- * Copyright (c) 2014-2019 Simon Fraser University
- * Copyright (c) 2000-2019 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class PKPRouter
  * @see PKPPageRouter
@@ -76,6 +76,8 @@ class PKPRouter {
 	var $_contexts = array();
 	/** @var PKPHandler Handler class */
 	var $_handler;
+	/** @var ?string */
+	var $_indexUrl;
 
 	/**
 	 * Constructor
@@ -220,16 +222,17 @@ class PKPRouter {
 	 * A Generic call to a context defining object (e.g. a Press, a Conference, or a SchedConf)
 	 * @param $request PKPRequest the request to be routed
 	 * @param $requestedContextLevel int (optional) the desired context level
+	 * @param $forceReload boolean (optional) Reset a context even if it's already been loaded
 	 * @return object
 	 */
-	function &getContext($request, $requestedContextLevel = 1) {
+	function &getContext($request, $requestedContextLevel = 1, $forceReload = false) {
 		// Handle context depth 0
 		if (!$this->_contextDepth) {
 			$nullVar = null;
 			return $nullVar;
 		}
 
-		if (!isset($this->_contexts[$requestedContextLevel])) {
+		if ($forceReload || !isset($this->_contexts[$requestedContextLevel])) {
 			// Retrieve the requested context path (this validates the context level and the path)
 			$path = $this->getRequestedContextPath($request, $requestedContextLevel);
 
@@ -341,7 +344,11 @@ class PKPRouter {
 	 * @param $authorizationMessage string a translation key with the authorization
 	 *  failure message.
 	 */
-	function handleAuthorizationFailure($request, $authorizationMessage) {
+	function handleAuthorizationFailure(
+		$request,
+		$authorizationMessage,
+		array $messageParams = []
+	) {
 		// Must be implemented by sub-classes.
 		assert(false);
 	}
@@ -537,7 +544,7 @@ class PKPRouter {
 						$additionalParameters[] = $key.($escape?'%5B%5D=':'[]=').rawurlencode($element);
 					}
 				} else {
-					$additionalParameters[] = $key.'='.rawurlencode($value);
+					$additionalParameters[] = $key.'='.rawurlencode($value ?? '');
 				}
 			}
 		}
@@ -626,5 +633,3 @@ class PKPRouter {
 		return $this->_flippedContextList[$contextName] + 1;
 	}
 }
-
-
