@@ -3,9 +3,9 @@
 /**
  * @file classes/user/UserDAO.inc.php
  *
- * Copyright (c) 2014-2019 Simon Fraser University
- * Copyright (c) 2000-2019 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class UserDAO
  * @ingroup user
@@ -39,40 +39,32 @@ class UserDAO extends DAO {
 	 * Retrieve a user by ID.
 	 * @param $userId int
 	 * @param $allowDisabled boolean
-	 * @return User
+	 * @return User?
 	 */
 	function getById($userId, $allowDisabled = true) {
 		$result = $this->retrieve(
 			'SELECT * FROM users WHERE user_id = ?' . ($allowDisabled?'':' AND disabled = 0'),
-			array((int) $userId)
+			[(int) $userId]
 		);
 
-		$user = null;
-		if ($result->RecordCount() != 0) {
-			$user =& $this->_returnUserFromRowWithData($result->GetRowAssoc(false));
-		}
-		$result->Close();
-		return $user;
+		$row = (array) $result->current();
+		return $row?$this->_returnUserFromRowWithData($row):null;
 	}
 
 	/**
 	 * Retrieve a user by username.
 	 * @param $username string
 	 * @param $allowDisabled boolean
-	 * @return User
+	 * @return User?
 	 */
-	function &getByUsername($username, $allowDisabled = true) {
+	function getByUsername($username, $allowDisabled = true) {
 		$result = $this->retrieve(
 			'SELECT * FROM users WHERE username = ?' . ($allowDisabled?'':' AND disabled = 0'),
-			array($username)
+			[$username]
 		);
 
-		$returner = null;
-		if ($result->RecordCount() != 0) {
-			$returner =& $this->_returnUserFromRowWithData($result->GetRowAssoc(false));
-		}
-		$result->Close();
-		return $returner;
+		$row = (array) $result->current();
+		return $row?$this->_returnUserFromRowWithData($row):null;
 	}
 
 	/**
@@ -80,60 +72,45 @@ class UserDAO extends DAO {
 	 * @param $settingName string
 	 * @param $settingValue string
 	 * @param $allowDisabled boolean
-	 * @return User
+	 * @return User?
 	 */
 	function getBySetting($settingName, $settingValue, $allowDisabled = true) {
 		$result = $this->retrieve(
 			'SELECT u.* FROM users u JOIN user_settings us ON (u.user_id = us.user_id) WHERE us.setting_name = ? AND us.setting_value = ?' . ($allowDisabled?'':' AND u.disabled = 0'),
-			array($settingName, $settingValue)
+			[$settingName, $settingValue]
 		);
-
-		$returner = null;
-		if ($result->RecordCount() != 0) {
-			$returner =& $this->_returnUserFromRowWithData($result->GetRowAssoc(false));
-		}
-		$result->Close();
-		return $returner;
+		$row = $result->current();
+		return $row?$this->_returnUserFromRowWithData((array) $row):null;
 	}
 
 	/**
 	 * Get the user by the TDL ID (implicit authentication).
 	 * @param $authstr string
 	 * @param $allowDisabled boolean
-	 * @return object User
+	 * @return User?
 	 */
-	function &getUserByAuthStr($authstr, $allowDisabled = true) {
+	function getUserByAuthStr($authstr, $allowDisabled = true) {
 		$result = $this->retrieve(
 			'SELECT * FROM users WHERE auth_str = ?' . ($allowDisabled?'':' AND disabled = 0'),
-			array($authstr)
+			[$authstr]
 		);
-
-		$returner = null;
-		if ($result->RecordCount() != 0) {
-			$returner =& $this->_returnUserFromRowWithData($result->GetRowAssoc(false));
-		}
-		$result->Close();
-		return $returner;
+		$row = $result->current();
+		return $row?$this->_returnUserFromRowWithData((array) $row):null;
 	}
 
 	/**
 	 * Retrieve a user by email address.
 	 * @param $email string
 	 * @param $allowDisabled boolean
-	 * @return User
+	 * @return User?
 	 */
-	function &getUserByEmail($email, $allowDisabled = true) {
+	function getUserByEmail($email, $allowDisabled = true) {
 		$result = $this->retrieve(
 			'SELECT * FROM users WHERE email = ?' . ($allowDisabled?'':' AND disabled = 0'),
-			array($email)
+			[$email]
 		);
-
-		$returner = null;
-		if ($result->RecordCount() != 0) {
-			$returner =& $this->_returnUserFromRowWithData($result->GetRowAssoc(false));
-		}
-		$result->Close();
-		return $returner;
+		$row = $result->current();
+		return $row?$this->_returnUserFromRowWithData((array) $row):null;
 	}
 
 	/**
@@ -141,20 +118,15 @@ class UserDAO extends DAO {
 	 * @param $username string
 	 * @param $password string encrypted password
 	 * @param $allowDisabled boolean
-	 * @return User
+	 * @return User?
 	 */
-	function &getUserByCredentials($username, $password, $allowDisabled = true) {
+	function getUserByCredentials($username, $password, $allowDisabled = true) {
 		$result = $this->retrieve(
 			'SELECT * FROM users WHERE username = ? AND password = ?' . ($allowDisabled?'':' AND disabled = 0'),
-			array($username, $password)
+			[$username, $password]
 		);
-
-		$returner = null;
-		if ($result->RecordCount() != 0) {
-			$returner =& $this->_returnUserFromRowWithData($result->GetRowAssoc(false));
-		}
-		$result->Close();
-		return $returner;
+		$row = $result->current();
+		return $row?$this->_returnUserFromRowWithData((array) $row):null;
 	}
 
 	/**
@@ -165,31 +137,30 @@ class UserDAO extends DAO {
 	 * @return DAOResultFactory containing matching Users
 	 */
 	function getReviewersForSubmission($contextId, $submissionId, $round) {
-		$params = array(
-			(int) $contextId,
-			ROLE_ID_REVIEWER,
-			(int) $submissionId,
-			(int) $round
-		);
-		$params = array_merge($this->getFetchParameters(), $params);
-
-		$result = $this->retrieve(
-			'SELECT	u.* ,
-			' . $this->getFetchColumns() . '
-			FROM	users u
-			LEFT JOIN user_user_groups uug ON (uug.user_id = u.user_id)
-			LEFT JOIN user_groups ug ON (ug.user_group_id = uug.user_group_id)
-			LEFT JOIN review_assignments r ON (r.reviewer_id = u.user_id)
-			' . $this->getFetchJoins() . '
-			WHERE	ug.context_id = ? AND
-			ug.role_id = ? AND
-			r.submission_id = ? AND
-			r.round = ?
-			' . $this->getOrderBy(),
-			$params
+		return new DAOResultFactory(
+			$this->retrieve(
+				'SELECT	u.* ,
+				' . $this->getFetchColumns() . '
+				FROM	users u
+				LEFT JOIN user_user_groups uug ON (uug.user_id = u.user_id)
+				LEFT JOIN user_groups ug ON (ug.user_group_id = uug.user_group_id)
+				LEFT JOIN review_assignments r ON (r.reviewer_id = u.user_id)
+				' . $this->getFetchJoins() . '
+				WHERE	ug.context_id = ? AND
+				ug.role_id = ? AND
+				r.submission_id = ? AND
+				r.round = ?
+				' . $this->getOrderBy(),
+				array_merge($this->getFetchParameters(), [
+					(int) $contextId,
+					ROLE_ID_REVIEWER,
+					(int) $submissionId,
+					(int) $round
+				])
+			),
+			$this, '_returnUserFromRowWithData'
 		);
 
-		return new DAOResultFactory($result, $this, '_returnUserFromRowWithData');
 	}
 
 	/**
@@ -201,16 +172,11 @@ class UserDAO extends DAO {
 	 * @return array matching Users
 	 */
 	function getReviewersNotAssignedToSubmission($contextId, $submissionId, &$reviewRound, $name = '') {
-		$reviewAssignmentDao = DAORegistry::getDAO('ReviewAssignmentDAO');
-
-		$params = array(
-			(int) $contextId,
-			ROLE_ID_REVIEWER,
-			(int) $reviewRound->getStageId(),
+		$params = array_merge(
+			[(int) $contextId, ROLE_ID_REVIEWER, (int) $reviewRound->getStageId()],
+			$this->getFetchParameters(),
+			[(int) $submissionId, (int) $reviewRound->getId()]
 		);
-		$params = array_merge($params, $this->getFetchParameters());
-		$params[] = (int) $submissionId;
-		$params[] = (int) $reviewRound->getId();
 		if (!empty($name)) {
 			$nameSearchJoins = 'LEFT JOIN user_settings usgs ON (u.user_id = usgs.user_id AND usgs.setting_name = \'' . IDENTITY_SETTING_GIVENNAME .'\')
 				LEFT JOIN user_settings usfs ON (u.user_id = usfs.user_id AND usfs.setting_name = \'' . IDENTITY_SETTING_FAMILYNAME .'\')';
@@ -219,7 +185,7 @@ class UserDAO extends DAO {
 
 		$result = $this->retrieve(
 			'SELECT	DISTINCT u.*,
-			' . $this->getFetchColumns() .'
+			' . $this->getFetchColumns() . '
 			FROM	users u
 			JOIN user_user_groups uug ON (uug.user_id = u.user_id)
 			JOIN user_groups ug ON (ug.user_group_id = uug.user_group_id AND ug.context_id = ? AND ug.role_id = ?)
@@ -248,6 +214,7 @@ class UserDAO extends DAO {
 		$user->setData('incompleteCount', (int) $row['incomplete_count']);
 		$user->setData('completeCount', (int) $row['complete_count']);
 		$user->setData('declinedCount', (int) $row['declined_count']);
+		$user->setData('cancelledCount', (int) $row['cancelled_count']);
 		$user->setData('averageTime', (int) $row['average_time']);
 
 		// 0 values should return null. They represent a reviewer with no ratings
@@ -266,8 +233,8 @@ class UserDAO extends DAO {
 	 * @param $callHook boolean
 	 * @return User
 	 */
-	function &_returnUserFromRowWithData($row, $callHook = true) {
-		$user =& $this->_returnUserFromRow($row, false);
+	function _returnUserFromRowWithData($row, $callHook = true) {
+		$user = $this->_returnUserFromRow($row, false);
 		$this->getDataObjectSettings('user_settings', 'user_id', $row['user_id'], $user);
 
 		if (isset($row['review_id'])) $user->review_id = $row['review_id'];
@@ -282,7 +249,7 @@ class UserDAO extends DAO {
 	 * @param $callHook boolean
 	 * @return User
 	 */
-	function &_returnUserFromRow($row, $callHook = true) {
+	function _returnUserFromRow($row, $callHook = true) {
 		$user = $this->newDataObject();
 		$user->setId($row['user_id']);
 		$user->setUsername($row['username']);
@@ -328,7 +295,7 @@ class UserDAO extends DAO {
 				VALUES
 				(?, ?, ?, ?, ?, ?, ?, ?, ?, %s, %s, %s, %s, ?, ?, ?, ?, ?, ?, ?)',
 				$this->datetimeToDB($user->getDateLastEmail()), $this->datetimeToDB($user->getDateRegistered()), $this->datetimeToDB($user->getDateValidated()), $this->datetimeToDB($user->getDateLastLogin())),
-			array(
+			[
 				$user->getUsername(),
 				$user->getPassword(),
 				$user->getEmail(),
@@ -345,7 +312,7 @@ class UserDAO extends DAO {
 				$user->getAuthStr(),
 				(int) $user->getInlineHelp(),
 				$user->getGossip(),
-			)
+			]
 		);
 
 		$user->setId($this->getInsertId());
@@ -357,28 +324,33 @@ class UserDAO extends DAO {
 	 * @copydoc DAO::getLocaleFieldNames
 	 */
 	function getLocaleFieldNames() {
-		return array('biography', 'signature', 'affiliation',
-			IDENTITY_SETTING_GIVENNAME, IDENTITY_SETTING_FAMILYNAME, 'preferredPublicName');
+		return ['biography', 'signature', 'affiliation',
+			IDENTITY_SETTING_GIVENNAME, IDENTITY_SETTING_FAMILYNAME, 'preferredPublicName'];
 	}
 
 	/**
 	 * @copydoc DAO::getAdditionalFieldNames()
 	 */
 	function getAdditionalFieldNames() {
-		return array_merge(parent::getAdditionalFieldNames(), array(
+		return array_merge(parent::getAdditionalFieldNames(), [
 			'orcid',
 			'apiKey',
 			'apiKeyEnabled',
-		));
+		]);
 	}
 
 	/**
 	 * @copydoc DAO::updateLocaleFields
 	 */
 	function updateLocaleFields($user) {
-		$this->updateDataObjectSettings('user_settings', $user, array(
-			'user_id' => (int) $user->getId()
-		));
+		$this->updateDataObjectSettings('user_settings', $user, [
+			'user_id' => (int) $user->getId(),
+			// assoc_type and assoc_id must be included for upsert, or PostgreSQL's ON CONFLICT will not work:
+			// "there is no unique or exclusion constraint matching the ON CONFLICT specification"
+			// However, no localized context-specific data is currently used, so we can rely on the pkey.
+			'assoc_type' => CONTEXT_SITE,
+			'assoc_id' => 0,
+		]);
 	}
 
 	/**
@@ -415,7 +387,7 @@ class UserDAO extends DAO {
 					gossip = ?
 				WHERE	user_id = ?',
 				$this->datetimeToDB($user->getDateLastEmail()), $this->datetimeToDB($user->getDateValidated()), $this->datetimeToDB($user->getDateLastLogin())),
-			array(
+			[
 				$user->getUsername(),
 				$user->getPassword(),
 				$user->getEmail(),
@@ -433,7 +405,7 @@ class UserDAO extends DAO {
 				(int) $user->getInlineHelp(),
 				$user->getGossip(),
 				(int) $user->getId(),
-			)
+			]
 		);
 	}
 
@@ -442,7 +414,7 @@ class UserDAO extends DAO {
 	 * @param $user User
 	 */
 	function deleteObject($user) {
-		return $this->deleteUserById($user->getId());
+		$this->deleteUserById($user->getId());
 	}
 
 	/**
@@ -450,8 +422,8 @@ class UserDAO extends DAO {
 	 * @param $userId int
 	 */
 	function deleteUserById($userId) {
-		$this->update('DELETE FROM user_settings WHERE user_id = ?', array((int) $userId));
-		return $this->update('DELETE FROM users WHERE user_id = ?', array((int) $userId));
+		$this->update('DELETE FROM user_settings WHERE user_id = ?', [(int) $userId]);
+		$this->update('DELETE FROM users WHERE user_id = ?', [(int) $userId]);
 	}
 
 	/**
@@ -462,8 +434,7 @@ class UserDAO extends DAO {
 	 */
 	function getUserFullName($userId, $allowDisabled = true) {
 		$user = $this->getById($userId, $allowDisabled);
-		if ($user) return $user->getFullName();
-		return null;
+		return $user?$user->getFullName():null;
 	}
 
 	/**
@@ -475,17 +446,10 @@ class UserDAO extends DAO {
 	function getUserEmail($userId, $allowDisabled = true) {
 		$result = $this->retrieve(
 			'SELECT email FROM users WHERE user_id = ?' . ($allowDisabled?'':' AND disabled = 0'),
-			array((int) $userId)
+			[(int) $userId]
 		);
-
-		if($result->RecordCount() == 0) {
-			$returner = false;
-		} else {
-			$returner = $result->fields[0];
-		}
-
-		$result->Close();
-		return $returner;
+		$row = $result->current();
+		return $row?$row->email:null;
 	}
 
 	/**
@@ -500,7 +464,7 @@ class UserDAO extends DAO {
 			FROM users u
 			' . $this->getFetchJoins() . '
 			LEFT JOIN roles r ON u.user_id=r.user_id
-			WHERE r.role_id IS NULL';
+			WHERE r.role_id IS NULL ';
 
 		$orderSql = $this->getOrderBy(); // FIXME Add "sort field" parameter?
 		$params = $this->getFetchParameters();
@@ -517,13 +481,11 @@ class UserDAO extends DAO {
 	 */
 	function userExistsById($userId, $allowDisabled = true) {
 		$result = $this->retrieve(
-			'SELECT COUNT(*) FROM users WHERE user_id = ?' . ($allowDisabled?'':' AND disabled = 0'),
-			array((int) $userId)
+			'SELECT COUNT(*) AS row_count FROM users WHERE user_id = ?' . ($allowDisabled?'':' AND disabled = 0'),
+			[(int) $userId]
 		);
-		$returner = isset($result->fields[0]) && $result->fields[0] != 0 ? true : false;
-
-		$result->Close();
-		return $returner;
+		$row = $result->current();
+		return $row && $row->row_count;
 	}
 
 	/**
@@ -535,13 +497,11 @@ class UserDAO extends DAO {
 	 */
 	function userExistsByUsername($username, $userId = null, $allowDisabled = true) {
 		$result = $this->retrieve(
-			'SELECT COUNT(*) FROM users WHERE username = ?' . (isset($userId) ? ' AND user_id != ?' : '') . ($allowDisabled?'':' AND disabled = 0'),
-			isset($userId) ? array($username, (int) $userId) : array($username)
+			'SELECT COUNT(*) AS row_count FROM users WHERE username = ?' . (isset($userId) ? ' AND user_id != ?' : '') . ($allowDisabled?'':' AND disabled = 0'),
+			isset($userId) ? [$username, (int) $userId] : [$username]
 		);
-		$returner = isset($result->fields[0]) && $result->fields[0] == 1 ? true : false;
-
-		$result->Close();
-		return $returner;
+		$row = $result->current();
+		return $row && $row->row_count;
 	}
 
 	/**
@@ -553,13 +513,11 @@ class UserDAO extends DAO {
 	 */
 	function userExistsByEmail($email, $userId = null, $allowDisabled = true) {
 		$result = $this->retrieve(
-			'SELECT COUNT(*) FROM users WHERE email = ?' . (isset($userId) ? ' AND user_id != ?' : '') . ($allowDisabled?'':' AND disabled = 0'),
-			isset($userId) ? array($email, (int) $userId) : array($email)
+			'SELECT COUNT(*) AS row_count FROM users WHERE email = ?' . (isset($userId) ? ' AND user_id != ?' : '') . ($allowDisabled?'':' AND disabled = 0'),
+			isset($userId) ? [$email, (int) $userId] : [$email]
 		);
-		$returner = isset($result->fields[0]) && $result->fields[0] == 1 ? true : false;
-
-		$result->Close();
-		return $returner;
+		$row = $result->current();
+		return $row && $row->row_count;
 	}
 
 	/**
@@ -570,9 +528,9 @@ class UserDAO extends DAO {
 	function changeSitePrimaryLocale($oldLocale, $newLocale) {
 		// remove all empty user names in the new locale
 		// so that we do not have to take care if we should insert or update them -- we can then only insert them if needed
-		$settingNames = array(IDENTITY_SETTING_GIVENNAME, IDENTITY_SETTING_FAMILYNAME, 'preferredPublicName');
+		$settingNames = [IDENTITY_SETTING_GIVENNAME, IDENTITY_SETTING_FAMILYNAME, 'preferredPublicName'];
 		foreach ($settingNames as $settingName) {
-			$params = array($newLocale, $settingName);
+			$params = [$newLocale, $settingName];
 			$this->update(
 				"DELETE from user_settings
 				WHERE locale = ? AND setting_name = ? AND setting_value = ''",
@@ -580,44 +538,38 @@ class UserDAO extends DAO {
 			);
 		}
 		// get all names of all users in the new locale
-		$params = array($newLocale, IDENTITY_SETTING_GIVENNAME, $newLocale, IDENTITY_SETTING_FAMILYNAME, $newLocale, 'preferredPublicName');
 		$result = $this->retrieve(
 			"SELECT DISTINCT us.user_id, usg.setting_value AS given_name, usf.setting_value AS family_name, usp.setting_value AS preferred_public_name
 			FROM user_settings us
 				LEFT JOIN user_settings usg ON (usg.user_id = us.user_id AND usg.locale = ? AND usg.setting_name = ?)
 				LEFT JOIN user_settings usf ON (usf.user_id = us.user_id AND usf.locale = ? AND usf.setting_name = ?)
 				LEFT JOIN user_settings usp ON (usp.user_id = us.user_id AND usp.locale = ? AND usp.setting_name = ?)",
-			$params
+			[$newLocale, IDENTITY_SETTING_GIVENNAME, $newLocale, IDENTITY_SETTING_FAMILYNAME, $newLocale, 'preferredPublicName']
 		);
-		while (!$result->EOF) {
-			$row = $result->GetRowAssoc(false);
-			$userId = $row['user_id'];
-			if (empty($row['given_name']) && empty($row['family_name']) && empty($row['preferred_public_name'])) {
+		foreach ($result as $row) {
+			$userId = $row->user_id;
+			if (empty($row->given_name) && empty($row->family_name) && empty($row->preferred_public_name)) {
 				// if no user name exists in the new locale, insert them all
 				foreach ($settingNames as $settingName) {
-					$params = array($newLocale, $settingName, $settingName, $oldLocale, $userId);
 					$this->update(
 						"INSERT INTO user_settings (user_id, locale, setting_name, setting_value, setting_type)
 						SELECT DISTINCT us.user_id, ?, ?, us.setting_value, 'string'
 						FROM user_settings us
 						WHERE us.setting_name = ? AND us.locale = ? AND us.user_id = ?",
-						$params
+						[$newLocale, $settingName, $settingName, $oldLocale, $userId]
 					);
 				}
-			} elseif (empty($row['given_name'])) {
+			} elseif (empty($row->given_name)) {
 				// if the given name does not exist in the new locale (but one of the other names do exist), insert it
-				$params = array($newLocale, IDENTITY_SETTING_GIVENNAME, IDENTITY_SETTING_GIVENNAME, $oldLocale, $userId);
 				$this->update(
 					"INSERT INTO user_settings (user_id, locale, setting_name, setting_value, setting_type)
 					SELECT DISTINCT us.user_id, ?, ?, us.setting_value, 'string'
 					FROM user_settings us
 					WHERE us.setting_name = ? AND us.locale = ? AND us.user_id = ?",
-					$params
+					[$newLocale, IDENTITY_SETTING_GIVENNAME, IDENTITY_SETTING_GIVENNAME, $oldLocale, $userId]
 				 );
 			}
-			$result->MoveNext();
 		}
-		$result->Close();
 	}
 
 	/**
@@ -636,14 +588,14 @@ class UserDAO extends DAO {
 		$locale = AppLocale::getLocale();
 		// the users register for the site, thus
 		// the site primary locale should be the default locale
-		$site = Application::getRequest()->getSite();
+		$site = Application::get()->getRequest()->getSite();
 		$primaryLocale = $site->getPrimaryLocale();
-		return array(
+		return [
 			IDENTITY_SETTING_GIVENNAME, $locale,
 			IDENTITY_SETTING_GIVENNAME, $primaryLocale,
 			IDENTITY_SETTING_FAMILYNAME, $locale,
 			IDENTITY_SETTING_FAMILYNAME, $primaryLocale,
-		);
+		];
 	}
 
 	/**
@@ -673,7 +625,5 @@ class UserDAO extends DAO {
 	function getOrderBy() {
 		return 'ORDER BY user_family, user_given';
 	}
-
 }
 
-
