@@ -3,9 +3,9 @@
 /**
  * @file plugins/importexport/users/filter/PKPUserUserXmlFilter.inc.php
  *
- * Copyright (c) 2014-2019 Simon Fraser University
- * Copyright (c) 2000-2019 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class PKPUserUserXmlFilter
  * @ingroup plugins_importexport_users
@@ -47,7 +47,7 @@ class PKPUserUserXmlFilter extends NativeExportFilter {
 	 */
 	function &process(&$users) {
 		// Create the XML document
-		$doc = new DOMDocument('1.0');
+		$doc = new DOMDocument('1.0', 'utf-8');
 		$deployment = $this->getDeployment();
 
 		$rootNode = $doc->createElementNS($deployment->getNamespace(), 'PKPUsers');
@@ -126,8 +126,8 @@ class PKPUserUserXmlFilter extends NativeExportFilter {
 			$this->createOptionalNode($doc, $userNode, 'disabled_reason', $user->getDisabledReason());
 		}
 
-		$userGroupAssignmentDao = DAORegistry::getDAO('UserGroupAssignmentDAO');
-		$userGroupDao = DAORegistry::getDAO('UserGroupDAO');
+		$userGroupAssignmentDao = DAORegistry::getDAO('UserGroupAssignmentDAO'); /* @var $userGroupAssignmentDao UserGroupAssignmentDAO */
+		$userGroupDao = DAORegistry::getDAO('UserGroupDAO'); /* @var $userGroupDao UserGroupDAO */
 		$assignedGroups = $userGroupAssignmentDao->getByUserId($user->getId(), $context->getId());
 		while ($assignedGroup = $assignedGroups->next()) {
 			$userGroup = $userGroupDao->getById($assignedGroup->getUserGroupId());
@@ -150,9 +150,9 @@ class PKPUserUserXmlFilter extends NativeExportFilter {
 		$context = $deployment->getContext();
 		$userGroupsNode = $doc->createElementNS($deployment->getNamespace(), 'user_groups');
 
-		$userGroupDao = DAORegistry::getDAO('UserGroupDAO');
+		$userGroupDao = DAORegistry::getDAO('UserGroupDAO'); /* @var $userGroupDao UserGroupDAO */
 		$userGroups = $userGroupDao->getByContextId($context->getId());
-		$filterDao = DAORegistry::getDAO('FilterDAO');
+		$filterDao = DAORegistry::getDAO('FilterDAO'); /* @var $filterDao FilterDAO */
 		$userGroupExportFilters = $filterDao->getObjectsByGroup('usergroup=>user-xml');
 		assert(count($userGroupExportFilters)==1); // Assert only a single serialization filter
 		$exportFilter = array_shift($userGroupExportFilters);
